import request from '@/config/axios'

// 内存监控日志 VO
export interface MonitorMemVO {
  id: number // 访问ID
  hostName: string // 主机名称
  hostIp: string // 服务器ip
  serverName: string // 服务名
  physicalTotal: number // 总物理内存
  physicalUsed: number // 已用物理内存
  physicalFree: number // 剩余物理内存
  physicalUsage: number // 物理内存使用率
  runtimeTotal: number // jvm运行总内存
  runtimeMax: number // jvm最大内存
  runtimeUsed: number // jvm已用内存
  runtimeFree: number // jvm空闲内存
  runtimeUsage: number // jvm内存使用率
}

// 内存监控日志 API
export const MonitorMemApi = {
  // 查询内存监控日志分页
  getMonitorMemPage: async (params: any) => {
    return await request.get({ url: `/infra/monitor-mem/page`, params })
  },

  // 查询统计数据列表
  getMonitorMemList: async (params: any) => {
    return await request.get({ url: `/infra/monitor-mem/getMonitorMemList`, params })
  },

  // 查询内存监控日志详情
  getMonitorMem: async (id: number) => {
    return await request.get({ url: `/infra/monitor-mem/get?id=` + id })
  },

  // 查询主机列表
  getAllHost: async () => {
    return await request.get({ url: `/infra/monitor-mem/getAllHost`})
  },

  // 查询ip列表
  getAllIp: async () => {
    return await request.get({ url: `/infra/monitor-mem/getAllIp`})
  },

  // 查询服务列表
  getAllServer: async () => {
    return await request.get({ url: `/infra/monitor-mem/getAllServer`})
  },

  // 新增内存监控日志
  createMonitorMem: async (data: MonitorMemVO) => {
    return await request.post({ url: `/infra/monitor-mem/create`, data })
  },

  // 修改内存监控日志
  updateMonitorMem: async (data: MonitorMemVO) => {
    return await request.put({ url: `/infra/monitor-mem/update`, data })
  },

  // 删除内存监控日志
  deleteMonitorMem: async (id: number) => {
    return await request.delete({ url: `/infra/monitor-mem/delete?id=` + id })
  },

  // 导出内存监控日志 Excel
  exportMonitorMem: async (params) => {
    return await request.download({ url: `/infra/monitor-mem/export-excel`, params })
  },
}
